@@ -97,11 +97,6 @@ sub _recommend_geo_coder_geocoder_us {
       This module is required for the 'satpass' script's 'geocode'
       command, but is otherwise unused by this package. If you do not
       intend to use this functionality, this package is not needed.
-EOD
-    eval { require SOAP::Lite; 1 }
-	and $recommendation .= <<'EOD';
-      The SOAP::Lite interface to the geocoding service is deprecated,
-      and will eventually be removed.
 EOD
     return $recommendation;
 }
@@ -220,7 +215,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2013 by Thomas R. Wyant, III
+Copyright (C) 2010-2014 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
